@@ -3,7 +3,7 @@
  *  Interface to GiNaC's indexed expressions. */
 
 /*
- *  GiNaC Copyright (C) 1999-2015 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2019 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -138,29 +138,29 @@ public:
 
 	// internal constructors
 	indexed(const symmetry & symm, const exprseq & es);
-	indexed(const symmetry & symm, const exvector & v, bool discardable = false);
-	indexed(const symmetry & symm, std::auto_ptr<exvector> vp);
+	indexed(const symmetry & symm, const exvector & v);
+	indexed(const symmetry & symm, exvector && v);
 
 	// functions overriding virtual functions from base classes
 public:
-	unsigned precedence() const {return 55;}
-	bool info(unsigned inf) const;
-	ex eval(int level = 0) const;
-	ex real_part() const;
-	ex imag_part() const;
-	exvector get_free_indices() const;
+	unsigned precedence() const override {return 55;}
+	bool info(unsigned inf) const override;
+	ex eval() const override;
+	ex real_part() const override;
+	ex imag_part() const override;
+	exvector get_free_indices() const override;
 
 	/** Save (a.k.a. serialize) indexed object into archive. */
-	void archive(archive_node& n) const;
+	void archive(archive_node& n) const override;
 	/** Read (a.k.a. deserialize) indexed object from archive. */
-	void read_archive(const archive_node& n, lst& syms);
+	void read_archive(const archive_node& n, lst& syms) override;
 protected:
-	ex derivative(const symbol & s) const;
-	ex thiscontainer(const exvector & v) const;
-	ex thiscontainer(std::auto_ptr<exvector> vp) const;
-	unsigned return_type() const;
-	return_type_t return_type_tinfo() const { return op(0).return_type_tinfo(); }
-	ex expand(unsigned options = 0) const;
+	ex derivative(const symbol & s) const override;
+	ex thiscontainer(const exvector & v) const override;
+	ex thiscontainer(exvector && v) const override;
+	unsigned return_type() const override;
+	return_type_t return_type_tinfo() const override { return op(0).return_type_tinfo(); }
+	ex expand(unsigned options = 0) const override;
 
 	// new virtual functions which can be overridden by derived classes
 	// none
