@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.4.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,11 +41,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.4"
+#define YYBISON_VERSION "3.4.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -61,8 +65,8 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 29 "ginsh_parser.ypp" /* yacc.c:339  */
+/* First part of user prologue.  */
+#line 29 "ginsh_parser.ypp"
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -150,13 +154,17 @@ static void insert_fcn_help(const char *name, const char *str);
 static void print_help(const string &topic);
 static void print_help_topics(void);
 
-#line 154 "ginsh_parser.cpp" /* yacc.c:339  */
+#line 158 "ginsh_parser.cpp"
 
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -168,8 +176,8 @@ static void print_help_topics(void);
 # define YYERROR_VERBOSE 0
 #endif
 
-/* In a future release of Bison, this section will be replaced
-   by #include "ginsh_parser.hpp".  */
+/* Use api.header.include to #include this header
+   instead of duplicating it here.  */
 #ifndef YY_YY_GINSH_PARSER_HPP_INCLUDED
 # define YY_YY_GINSH_PARSER_HPP_INCLUDED
 /* Debug traces.  */
@@ -253,9 +261,7 @@ int yyparse (void);
 
 #endif /* !YY_YY_GINSH_PARSER_HPP_INCLUDED  */
 
-/* Copy the second part of user declarations.  */
 
-#line 259 "ginsh_parser.cpp" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -276,13 +282,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -294,7 +300,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -330,15 +336,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -346,7 +343,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -366,6 +363,8 @@ typedef short int yytype_int16;
 #endif
 
 
+#define YY_ASSERT(E) ((void) (0 && (E)))
+
 #if ! defined yyoverflow || YYERROR_VERBOSE
 
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
@@ -508,16 +507,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  122
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   282
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -785,22 +784,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -840,37 +839,39 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   YYUSE (yytype);
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
-  YYFPRINTF (yyoutput, ")");
+  yy_symbol_value_print (yyo, yytype, yyvaluep);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -904,7 +905,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -915,7 +916,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                                               );
       YYFPRINTF (stderr, "\n");
     }
@@ -1019,7 +1020,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -1037,7 +1041,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -1115,10 +1119,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -1130,6 +1134,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1141,9 +1146,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1269,23 +1275,33 @@ yyparse (void)
   yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
-  *yyssp = yystate;
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
+  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
+  YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1301,14 +1317,10 @@ yyparse (void)
                     &yyss1, yysize * sizeof (*yyssp),
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yystacksize);
-
         yyss = yyss1;
         yyvs = yyvs1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1324,35 +1336,33 @@ yyparse (void)
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
-
-  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   if (yystate == YYFINAL)
     YYACCEPT;
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1410,7 +1420,6 @@ yybackup:
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
   YY_IGNORE_MAYBE_UNINITIALIZED_END
-
   goto yynewstate;
 
 
@@ -1425,7 +1434,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1445,51 +1454,51 @@ yyreduce:
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
-        case 5:
-#line 148 "ginsh_parser.ypp" /* yacc.c:1646  */
+  case 5:
+#line 148 "ginsh_parser.ypp"
     {
 		try {
-			cout << (yyvsp[-1]) << endl;
-			push((yyvsp[-1]));
+			cout << yyvsp[-1] << endl;
+			push(yyvsp[-1]);
 		} catch (exception &e) {
 			cerr << e.what() << endl;
 			YYERROR;
 		}
 	}
-#line 1460 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1469 "ginsh_parser.cpp"
     break;
 
   case 6:
-#line 157 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 157 "ginsh_parser.ypp"
     {
 		try {
-			push((yyvsp[-1]));
+			push(yyvsp[-1]);
 		} catch (exception &e) {
 			std::cerr << e.what() << endl;
 			YYERROR;
 		}
 	}
-#line 1473 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1482 "ginsh_parser.cpp"
     break;
 
   case 7:
-#line 165 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 165 "ginsh_parser.ypp"
     {
 		try {
-			(yyvsp[-2]).print(print_tree(std::cout));
+			yyvsp[-2].print(print_tree(std::cout));
 		} catch (exception &e) {
 			std::cerr << e.what() << endl;
 			YYERROR;
 		}
 	}
-#line 1486 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1495 "ginsh_parser.cpp"
     break;
 
   case 8:
-#line 173 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 173 "ginsh_parser.ypp"
     {
 		try {
-			ex e = (yyvsp[-2]);
+			ex e = yyvsp[-2];
 			if (!e.info(info_flags::integer))
 				throw (std::invalid_argument("argument to iprint() must be an integer"));
 			long i = ex_to<numeric>(e).to_long();
@@ -1501,85 +1510,85 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1505 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1514 "ginsh_parser.cpp"
     break;
 
   case 9:
-#line 187 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 187 "ginsh_parser.ypp"
     {
 		try {
-			(yyvsp[-2]).print(print_latex(std::cout)); cout << endl;
+			yyvsp[-2].print(print_latex(std::cout)); cout << endl;
 		} catch (exception &e) {
 			std::cerr << e.what() << endl;
 			YYERROR;
 		}
 	}
-#line 1518 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1527 "ginsh_parser.cpp"
     break;
 
   case 10:
-#line 195 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 195 "ginsh_parser.ypp"
     {
 		try {
-			(yyvsp[-2]).print(print_csrc_double(std::cout)); cout << endl;
+			yyvsp[-2].print(print_csrc_double(std::cout)); cout << endl;
 		} catch (exception &e) {
 			std::cerr << e.what() << endl;
 			YYERROR;
 		}
 	}
-#line 1531 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1540 "ginsh_parser.cpp"
     break;
 
   case 11:
-#line 203 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {print_help(ex_to<symbol>((yyvsp[0])).get_name());}
-#line 1537 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 203 "ginsh_parser.ypp"
+    {print_help(ex_to<symbol>(yyvsp[0]).get_name());}
+#line 1546 "ginsh_parser.cpp"
     break;
 
   case 12:
-#line 204 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 204 "ginsh_parser.ypp"
     {print_help("time");}
-#line 1543 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1552 "ginsh_parser.cpp"
     break;
 
   case 13:
-#line 205 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 205 "ginsh_parser.ypp"
     {print_help("print");}
-#line 1549 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1558 "ginsh_parser.cpp"
     break;
 
   case 14:
-#line 206 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 206 "ginsh_parser.ypp"
     {print_help("iprint");}
-#line 1555 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1564 "ginsh_parser.cpp"
     break;
 
   case 15:
-#line 207 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 207 "ginsh_parser.ypp"
     {print_help("print_latex");}
-#line 1561 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1570 "ginsh_parser.cpp"
     break;
 
   case 16:
-#line 208 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 208 "ginsh_parser.ypp"
     {print_help("print_csrc");}
-#line 1567 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1576 "ginsh_parser.cpp"
     break;
 
   case 17:
-#line 209 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 209 "ginsh_parser.ypp"
     {print_help_topics();}
-#line 1573 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1582 "ginsh_parser.cpp"
     break;
 
   case 18:
-#line 210 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 210 "ginsh_parser.ypp"
     {YYACCEPT;}
-#line 1579 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1588 "ginsh_parser.cpp"
     break;
 
   case 19:
-#line 211 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 211 "ginsh_parser.ypp"
     {
 		cout << "This program is free software; you can redistribute it and/or modify it under\n";
 		cout << "the terms of the GNU General Public License as published by the Free Software\n";
@@ -1593,316 +1602,317 @@ yyreduce:
 		cout << "this program. If not, write to the Free Software Foundation,\n";
 		cout << "51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.\n";
 	}
-#line 1597 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1606 "ginsh_parser.cpp"
     break;
 
   case 20:
-#line 224 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 224 "ginsh_parser.ypp"
     {cout << "Nothing happens.\n";}
-#line 1603 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1612 "ginsh_parser.cpp"
     break;
 
   case 21:
-#line 225 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 225 "ginsh_parser.ypp"
     {cout << "You're not carrying anything.\n";}
-#line 1609 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1618 "ginsh_parser.cpp"
     break;
 
   case 22:
-#line 226 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 226 "ginsh_parser.ypp"
     {cout << "You're in a twisty little maze of passages, all alike.\n";}
-#line 1615 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1624 "ginsh_parser.cpp"
     break;
 
   case 23:
-#line 227 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 227 "ginsh_parser.ypp"
     {
 		cout << "If you were to quit now, you would score ";
 		cout << (syms.size() > 350 ? 350 : syms.size());
 		cout << " out of a possible 350.\n";
 	}
-#line 1625 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1634 "ginsh_parser.cpp"
     break;
 
   case 24:
-#line 232 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 232 "ginsh_parser.ypp"
     { symboltype = domain::real; }
-#line 1631 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1640 "ginsh_parser.cpp"
     break;
 
   case 25:
-#line 233 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 233 "ginsh_parser.ypp"
     { symboltype = domain::complex; }
-#line 1637 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1646 "ginsh_parser.cpp"
     break;
 
   case 26:
-#line 234 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 234 "ginsh_parser.ypp"
     { START_TIMER }
-#line 1643 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1652 "ginsh_parser.cpp"
     break;
 
   case 27:
-#line 234 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 234 "ginsh_parser.ypp"
     { STOP_TIMER PRINT_TIME_USED }
-#line 1649 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1658 "ginsh_parser.cpp"
     break;
 
   case 28:
-#line 235 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 235 "ginsh_parser.ypp"
     {yyclearin; yyerrok;}
-#line 1655 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1664 "ginsh_parser.cpp"
     break;
 
   case 29:
-#line 236 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 236 "ginsh_parser.ypp"
     {yyclearin; yyerrok;}
-#line 1661 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1670 "ginsh_parser.cpp"
     break;
 
   case 30:
-#line 239 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[0]);}
-#line 1667 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 239 "ginsh_parser.ypp"
+    {yyval = yyvsp[0];}
+#line 1676 "ginsh_parser.cpp"
     break;
 
   case 31:
-#line 240 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 240 "ginsh_parser.ypp"
     {
-		auto i = assigned_symbol_table.find((yyvsp[0]));
+		auto i = assigned_symbol_table.find(yyvsp[0]);
 		if (i == assigned_symbol_table.end())
-			(yyval) = (yyvsp[0]);
+			yyval = yyvsp[0];
 		else
-			(yyval) = i->second;
+			yyval = i->second;
 	}
-#line 1679 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1688 "ginsh_parser.cpp"
     break;
 
   case 32:
-#line 247 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[-1]);}
-#line 1685 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 247 "ginsh_parser.ypp"
+    {yyval = yyvsp[-1];}
+#line 1694 "ginsh_parser.cpp"
     break;
 
   case 33:
-#line 248 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[0]);}
-#line 1691 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 248 "ginsh_parser.ypp"
+    {yyval = yyvsp[0];}
+#line 1700 "ginsh_parser.cpp"
     break;
 
   case 34:
-#line 249 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[0]);}
-#line 1697 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 249 "ginsh_parser.ypp"
+    {yyval = yyvsp[0];}
+#line 1706 "ginsh_parser.cpp"
     break;
 
   case 35:
-#line 250 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = exstack[0];}
-#line 1703 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 250 "ginsh_parser.ypp"
+    {yyval = exstack[0];}
+#line 1712 "ginsh_parser.cpp"
     break;
 
   case 36:
-#line 251 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = exstack[1];}
-#line 1709 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 251 "ginsh_parser.ypp"
+    {yyval = exstack[1];}
+#line 1718 "ginsh_parser.cpp"
     break;
 
   case 37:
-#line 252 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = exstack[2];}
-#line 1715 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 252 "ginsh_parser.ypp"
+    {yyval = exstack[2];}
+#line 1724 "ginsh_parser.cpp"
     break;
 
   case 38:
-#line 253 "ginsh_parser.ypp" /* yacc.c:1646  */
+#line 253 "ginsh_parser.ypp"
     {
-		auto i = find_function((yyvsp[-3]), (yyvsp[-1]).nops());
+		auto i = find_function(yyvsp[-3], yyvsp[-1].nops());
 		if (i->second.is_ginac) {
-			(yyval) = ((fcnp2)(i->second.p))(ex_to<exprseq>((yyvsp[-1])), i->second.serial);
+			yyval = ((fcnp2)(i->second.p))(ex_to<exprseq>(yyvsp[-1]), i->second.serial);
 		} else {
-			(yyval) = (i->second.p)(ex_to<exprseq>((yyvsp[-1])));
+			yyval = (i->second.p)(ex_to<exprseq>(yyvsp[-1]));
 		}
 	}
-#line 1728 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1737 "ginsh_parser.cpp"
     break;
 
   case 39:
-#line 261 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[0]); Digits = ex_to<numeric>((yyvsp[0])).to_int();}
-#line 1734 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 261 "ginsh_parser.ypp"
+    {yyval = yyvsp[0]; Digits = ex_to<numeric>(yyvsp[0]).to_int();}
+#line 1743 "ginsh_parser.cpp"
     break;
 
   case 40:
-#line 262 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[0]); assigned_symbol_table[(yyvsp[-2])] = (yyvsp[0]); }
-#line 1740 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 262 "ginsh_parser.ypp"
+    {yyval = yyvsp[0]; assigned_symbol_table[yyvsp[-2]] = yyvsp[0]; }
+#line 1749 "ginsh_parser.cpp"
     break;
 
   case 41:
-#line 263 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[-2]) == (yyvsp[0]);}
-#line 1746 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 263 "ginsh_parser.ypp"
+    {yyval = yyvsp[-2] == yyvsp[0];}
+#line 1755 "ginsh_parser.cpp"
     break;
 
   case 42:
-#line 264 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[-2]) != (yyvsp[0]);}
-#line 1752 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 264 "ginsh_parser.ypp"
+    {yyval = yyvsp[-2] != yyvsp[0];}
+#line 1761 "ginsh_parser.cpp"
     break;
 
   case 43:
-#line 265 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[-2]) < (yyvsp[0]);}
-#line 1758 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 265 "ginsh_parser.ypp"
+    {yyval = yyvsp[-2] < yyvsp[0];}
+#line 1767 "ginsh_parser.cpp"
     break;
 
   case 44:
-#line 266 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[-2]) <= (yyvsp[0]);}
-#line 1764 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 266 "ginsh_parser.ypp"
+    {yyval = yyvsp[-2] <= yyvsp[0];}
+#line 1773 "ginsh_parser.cpp"
     break;
 
   case 45:
-#line 267 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[-2]) > (yyvsp[0]);}
-#line 1770 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 267 "ginsh_parser.ypp"
+    {yyval = yyvsp[-2] > yyvsp[0];}
+#line 1779 "ginsh_parser.cpp"
     break;
 
   case 46:
-#line 268 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[-2]) >= (yyvsp[0]);}
-#line 1776 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 268 "ginsh_parser.ypp"
+    {yyval = yyvsp[-2] >= yyvsp[0];}
+#line 1785 "ginsh_parser.cpp"
     break;
 
   case 47:
-#line 269 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[-2]) + (yyvsp[0]);}
-#line 1782 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 269 "ginsh_parser.ypp"
+    {yyval = yyvsp[-2] + yyvsp[0];}
+#line 1791 "ginsh_parser.cpp"
     break;
 
   case 48:
-#line 270 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[-2]) - (yyvsp[0]);}
-#line 1788 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 270 "ginsh_parser.ypp"
+    {yyval = yyvsp[-2] - yyvsp[0];}
+#line 1797 "ginsh_parser.cpp"
     break;
 
   case 49:
-#line 271 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[-2]) * (yyvsp[0]);}
-#line 1794 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 271 "ginsh_parser.ypp"
+    {yyval = yyvsp[-2] * yyvsp[0];}
+#line 1803 "ginsh_parser.cpp"
     break;
 
   case 50:
-#line 272 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[-2]) / (yyvsp[0]);}
-#line 1800 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 272 "ginsh_parser.ypp"
+    {yyval = yyvsp[-2] / yyvsp[0];}
+#line 1809 "ginsh_parser.cpp"
     break;
 
   case 51:
-#line 273 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = -(yyvsp[0]);}
-#line 1806 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 273 "ginsh_parser.ypp"
+    {yyval = -yyvsp[0];}
+#line 1815 "ginsh_parser.cpp"
     break;
 
   case 52:
-#line 274 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[0]);}
-#line 1812 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 274 "ginsh_parser.ypp"
+    {yyval = yyvsp[0];}
+#line 1821 "ginsh_parser.cpp"
     break;
 
   case 53:
-#line 275 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = power((yyvsp[-2]), (yyvsp[0]));}
-#line 1818 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 275 "ginsh_parser.ypp"
+    {yyval = power(yyvsp[-2], yyvsp[0]);}
+#line 1827 "ginsh_parser.cpp"
     break;
 
   case 54:
-#line 276 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = factorial((yyvsp[-1]));}
-#line 1824 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 276 "ginsh_parser.ypp"
+    {yyval = factorial(yyvsp[-1]);}
+#line 1833 "ginsh_parser.cpp"
     break;
 
   case 55:
-#line 277 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[-1]);}
-#line 1830 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 277 "ginsh_parser.ypp"
+    {yyval = yyvsp[-1];}
+#line 1839 "ginsh_parser.cpp"
     break;
 
   case 56:
-#line 278 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[-1]);}
-#line 1836 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 278 "ginsh_parser.ypp"
+    {yyval = yyvsp[-1];}
+#line 1845 "ginsh_parser.cpp"
     break;
 
   case 57:
-#line 279 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = lst_to_matrix(ex_to<lst>((yyvsp[-1])));}
-#line 1842 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 279 "ginsh_parser.ypp"
+    {yyval = lst_to_matrix(ex_to<lst>(yyvsp[-1]));}
+#line 1851 "ginsh_parser.cpp"
     break;
 
   case 58:
-#line 282 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = exprseq{(yyvsp[0])};}
-#line 1848 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 282 "ginsh_parser.ypp"
+    {yyval = exprseq{yyvsp[0]};}
+#line 1857 "ginsh_parser.cpp"
     break;
 
   case 59:
-#line 283 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {exprseq es(ex_to<exprseq>((yyvsp[-2]))); (yyval) = es.append((yyvsp[0]));}
-#line 1854 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 283 "ginsh_parser.ypp"
+    {exprseq es(ex_to<exprseq>(yyvsp[-2])); yyval = es.append(yyvsp[0]);}
+#line 1863 "ginsh_parser.cpp"
     break;
 
   case 60:
-#line 286 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = *new lst;}
-#line 1860 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 286 "ginsh_parser.ypp"
+    {yyval = *new lst;}
+#line 1869 "ginsh_parser.cpp"
     break;
 
   case 61:
-#line 287 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = (yyvsp[0]);}
-#line 1866 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 287 "ginsh_parser.ypp"
+    {yyval = yyvsp[0];}
+#line 1875 "ginsh_parser.cpp"
     break;
 
   case 62:
-#line 290 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = lst{(yyvsp[0])};}
-#line 1872 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 290 "ginsh_parser.ypp"
+    {yyval = lst{yyvsp[0]};}
+#line 1881 "ginsh_parser.cpp"
     break;
 
   case 63:
-#line 291 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {lst l(ex_to<lst>((yyvsp[-2]))); (yyval) = l.append((yyvsp[0]));}
-#line 1878 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 291 "ginsh_parser.ypp"
+    {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
+#line 1887 "ginsh_parser.cpp"
     break;
 
   case 64:
-#line 294 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = lst{(yyvsp[-1])};}
-#line 1884 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 294 "ginsh_parser.ypp"
+    {yyval = lst{yyvsp[-1]};}
+#line 1893 "ginsh_parser.cpp"
     break;
 
   case 65:
-#line 295 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {lst l(ex_to<lst>((yyvsp[-4]))); (yyval) = l.append((yyvsp[-1]));}
-#line 1890 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 295 "ginsh_parser.ypp"
+    {lst l(ex_to<lst>(yyvsp[-4])); yyval = l.append(yyvsp[-1]);}
+#line 1899 "ginsh_parser.cpp"
     break;
 
   case 66:
-#line 298 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {(yyval) = lst{(yyvsp[0])};}
-#line 1896 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 298 "ginsh_parser.ypp"
+    {yyval = lst{yyvsp[0]};}
+#line 1905 "ginsh_parser.cpp"
     break;
 
   case 67:
-#line 299 "ginsh_parser.ypp" /* yacc.c:1646  */
-    {lst l(ex_to<lst>((yyvsp[-2]))); (yyval) = l.append((yyvsp[0]));}
-#line 1902 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 299 "ginsh_parser.ypp"
+    {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
+#line 1911 "ginsh_parser.cpp"
     break;
 
 
-#line 1906 "ginsh_parser.cpp" /* yacc.c:1646  */
+#line 1915 "ginsh_parser.cpp"
+
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1927,14 +1937,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -2017,12 +2026,10 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
-
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -2084,6 +2091,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -2091,6 +2099,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -2101,6 +2110,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -2130,7 +2143,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 307 "ginsh_parser.ypp" /* yacc.c:1906  */
+#line 307 "ginsh_parser.ypp"
 
 // Error print routine
 int yyerror(const char *s)
@@ -2703,7 +2716,7 @@ static void ginsh_readline_init(char* name)
 void greeting(void)
 {
     cout << "ginsh - GiNaC Interactive Shell (GiNaC V" << GINACLIB_VERSION << ")" << endl;
-    cout << "  __,  _______  Copyright (C) 1999-2018 Johannes Gutenberg University Mainz,\n"
+    cout << "  __,  _______  Copyright (C) 1999-2019 Johannes Gutenberg University Mainz,\n"
          << " (__) *       | Germany.  This is free software with ABSOLUTELY NO WARRANTY.\n"
          << "  ._) i N a C | You are welcome to redistribute it under certain conditions.\n"
          << "<-------------' For details type `warranty;'.\n" << endl;
